@@ -6,4 +6,4 @@ Created on Wed Sep  8 18:50:45 2021
 @author: patrick
 """
 
-from ./Facebook_Chat_Analysis import *
+from .Facebook_Chat_Analysis import *
